@@ -50,14 +50,14 @@ def extract_audio_from_video(video_path, audio_path):
         logging.error(f"Error extracting audio from {video_path}: {e}")
         return None
 
-def transcribe_audio_file(audio_path, text_path, json_path, chunk_length_ms=60000):
+def transcribe_audio_file(audio_path, json_data, chunk_length_ms=60000,summarizer=None):
     """Transcribe audio file in chunks and save as text and time-blocked JSON."""
     try:
         logging.info(f"Transcribing audio: {audio_path}")
         audio = AudioSegment.from_wav(audio_path)
         chunks = [audio[i:i + chunk_length_ms] for i in range(0, len(audio), chunk_length_ms)]
         full_text = ""
-        json_data = []
+        json_data['audio_text'] = []
 
         for i, chunk in enumerate(chunks):
             start_time = i * chunk_length_ms
@@ -72,21 +72,21 @@ def transcribe_audio_file(audio_path, text_path, json_path, chunk_length_ms=6000
                 try:
                     text = r.recognize_google(audio_data)
                     full_text += text + " "
-                    json_data.append({
+                    json_data['audio_text'].append({
                         "start_time": format_timestamp(start_time),
                         "end_time": format_timestamp(end_time),
                         "text": text
                     })
                 except sr.UnknownValueError:
                     logging.warning(f"Chunk {i+1} could not be transcribed.")
-                    json_data.append({
+                    json_data['audio_text'].append({
                         "start_time": format_timestamp(start_time),
                         "end_time": format_timestamp(end_time),
                         "text": ""
                     })
                 except sr.RequestError as e:
                     logging.error(f"API error for chunk {i+1}: {e}")
-                    json_data.append({
+                    json_data['audio_text'].append({
                         "start_time": format_timestamp(start_time),
                         "end_time": format_timestamp(end_time),
                         "text": ""
@@ -95,65 +95,53 @@ def transcribe_audio_file(audio_path, text_path, json_path, chunk_length_ms=6000
 
         # Save plain text
         if full_text:
-            text_result, text_path = save_voice(full_text.strip(), text_path)
-        else:
-            text_result, text_path = save_voice("", text_path)
-            logging.warning(f"No text transcribed for {audio_path}")
+            full_text = full_text.strip()
+        text_result= get_voice(full_text, text=full_text)
+        json_data['full_text']=text_result
+        json_data['summary']=None
+        if summarizer:
+            try:
+                json_data['summary'] = summarizer(text_result, max_length=160, min_length=40)
+            except Exception as e:
+                logging.error(f"Error getting summary for {json_data['filename']}: {e}")
 
-        # Save JSON
-        try:
-            safe_dump_to_file(data=json_data, file_path=json_path)
-            logging.info(f"JSON transcription saved to {json_path}")
-        except Exception as e:
-            logging.error(f"Error saving JSON to {json_path}: {e}")
-
-        return text_result, text_path
+        return json_data
     except Exception as e:
         logging.error(f"Error transcribing {audio_path}: {e}")
-        return None, text_path
+        return None, json_path
 
-def save_voice(voice, voice_txt_path):
+def get_voice(voice, text=None):
     """Save transcribed text to a file."""
-    voice_txt_path = voice_txt_path or 'voice.txt'
-    if not os.path.isfile(voice_txt_path):
-        write_to_file(contents = '',file_path = voice_txt_path)
-    text = read_from_file(voice_txt_path)
-    try:
-        if voice:
-            text = text + '\n' + str(voice) if text else str(voice)
-            write_to_file(contents=text, file_path=voice_txt_path)
-            logging.info(f"Text saved to {voice_txt_path}")
-            
-        else:
-            logging.info(f"voice not a valid value {voice_txt_path}")
-        
-    except Exception as e:
-        logging.info(f"Error saving text to {voice_txt_path}: {e}")
-    return text, voice_txt_path
+    text = text or ''
+    if voice:
+        text = text + '\n' + str(voice) if text else str(voice)
+       
+    return text
     
 def initiate_process(target,*args):
     p = Process(target=target, args=args)
     p.start()
     logging.info(f"Started process for: {args}")
-def transcribe_all_video_paths(directory=None,output_directory=None):
+def transcribe_all_video_paths(directory=None,output_dir=None,remove_phrases=None,summarizer=None):
+    remove_phrases=remove_phrases or []
     directory = directory or os.getcwd()
-    output_directory = output_directory if output_directory else make_dirs(directory,'text_dir')
+    output_dir = output_dir if output_dir else make_dirs(directory,'text_dir')
     paths = glob.glob(path_join(directory, '**', '**'), recursive=True)
     paths = [file_path for file_path in paths if confirm_type(file_path,media_types=get_media_types(['video']))]
     video_paths = get_all_file_types(directory=directory,types='video') or get_all_file_types(directory=abs_dirname,types='videos')
     for video_path in video_paths:
-        transcribe_audio(video_path,ourput_dir=output_directory)
-def transcribe_audio(video_path,ourput_dir=None):
+        transcribe_audio(video_path,output_dir=output_dir,remove_phrases=remove_phrases,summarizer=summarizer)
+def transcribe_audio(video_path,output_dir=None,remove_phrases=None,summarizer=None):
+    remove_phrases=remove_phrases or []
     dirname = os.path.dirname(video_path)
     basename = os.path.basename(video_path)
     filename,ext = os.path.splitext(basename)
-    video_directory = make_dirs(ourput_dir,filename)
+    video_directory = make_dirs(output_dir,filename)
     info_path = os.path.join(video_directory,'info.json')
-    text_path = os.path.join(video_directory,'text.txt')
-    json_path = os.path.join(video_directory,'video_text.json')
+    video_text_path = os.path.join(video_directory,'video_text.json')
     audio_path = os.path.join(video_directory,'audio.wav')
     video_json_path = os.path.join(video_directory,'video_json.json')
-    args_tuple = (video_path, video_directory, video_json_path, [], '', filename)
+    args_tuple = (video_path, video_directory, video_json_path, [], '', filename,remove_phrases,summarizer)
     initiate_process(derive_all_video_meta, *args_tuple)
     info = {}
     info['video_path']=video_path
@@ -161,13 +149,10 @@ def transcribe_audio(video_path,ourput_dir=None):
     info['info_path']=info_path
     info['filename']=filename
     info['ext']=ext
-    info['text_path']=text_path
     info['audio_path']=audio_path
-    info['json_path']=json_path
     info['video_json']=video_json_path
-    safe_dump_to_file(data=info,file_path=info['info_path'])
-    extract_audio_from_video(video_path=info['video_path'],audio_path=info['audio_path'])
-    transcribe_audio_file(audio_path=info['audio_path'],text_path=info['text_path'],json_path=info['json_path'])
-        
+    extract_audio_from_video(video_path=info['video_path'],audio_path=info['audio_path'],summarizer=summarizer)
+    info = transcribe_audio_file(audio_path=info['audio_path'],json_data=info)
+    safe_dump_to_file(data=info,file_path=info['info_path']) 
    
     
