@@ -9,6 +9,51 @@ import numpy as np
 import re
 import os
 import requests
+import cv2
+import pytesseract
+import numpy as np
+from PIL import Image
+import re
+
+def preprocess_for_ocr(image_path: str) -> np.ndarray:
+    img = cv2.imread(image_path)
+    gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
+
+    # Enhance contrast
+    clahe = cv2.createCLAHE(clipLimit=2.0, tileGridSize=(8, 8))
+    contrast = clahe.apply(gray)
+
+    # Denoise
+    denoised = cv2.bilateralFilter(contrast, d=9, sigmaColor=75, sigmaSpace=75)
+
+    # Thresholding
+    thresh = cv2.adaptiveThreshold(
+        denoised,
+        255,
+        cv2.ADAPTIVE_THRESH_GAUSSIAN_C,
+        cv2.THRESH_BINARY_INV,
+        blockSize=11,
+        C=2
+    )
+
+    # Sharpen
+    sharpen_kernel = np.array([[-1, -1, -1], [-1, 9, -1], [-1, -1, -1]])
+    sharpened = cv2.filter2D(thresh, -1, sharpen_kernel)
+
+    return sharpened
+
+def extract_text_from_image(image_path: str) -> str:
+    try:
+        processed_img = preprocess_for_ocr(image_path)
+        pil_img = Image.fromarray(cv2.bitwise_not(processed_img))  # invert for OCR
+        text = pytesseract.image_to_string(pil_img, lang='eng')
+        return text
+    except Exception as e:
+        print(f"[OCR Error] {e}")
+        return ""
+
+
+
 def download_pdf(url: str, output_path: str):
     response = requests.get(url, stream=True)
     if response.status_code == 200:
